@@ -11,6 +11,7 @@ from .sorter import Sorter, SorterAgeBased, SorterAlpha, SorterUseNetworkX, Sort
 from .stratigraphic_column import StratigraphicColumn
 from .deformation_history import DeformationHistory
 from .map2model_wrapper import Map2ModelWrapper
+from .data_checks import validate_config_dictionary
 
 # external imports
 import LoopProjectFile as LPF
@@ -18,7 +19,7 @@ from osgeo import gdal
 gdal.UseExceptions()
 import geopandas
 import beartype
-from beartype.typing import Union, List
+from beartype.typing import Union, List, Dict, Any
 import pathlib
 import numpy
 import pandas
@@ -34,7 +35,7 @@ class Project(object):
     """
     The main entry point into using map2loop
 
-    Attiributes
+    Attributes
     -----------
     verbose_level: m2l_enums.VerboseLevel
         A selection that defines how much console logging is output
@@ -74,8 +75,7 @@ class Project(object):
         save_pre_checked_map_data: bool = False,
         loop_project_filename: str = "",
         overwrite_loopprojectfile: bool = False,
-        **kwargs,
-    ):
+    ):  
         """
         The initialiser for the map2loop project
 
@@ -119,6 +119,19 @@ class Project(object):
             TypeError: Type of bounding_box not a dict or tuple
             ValueError: use_australian_state_data not in state list ['WA', 'SA', 'QLD', 'NSW', 'TAS', 'VIC', 'ACT', 'NT']
         """
+        
+        # make sure all the needed arguments are provided
+        if not use_australian_state_data: # this check has to skip if using Loop server data
+            self.validate_required_inputs(
+                bounding_box=bounding_box,
+                working_projection=working_projection,
+                geology_filename=geology_filename,
+                structure_filename=structure_filename,
+                dtm_filename=dtm_filename,
+                config_dictionary=config_dictionary,
+                config_filename=config_filename,
+            )
+        
         self._error_state = ErrorState.NONE
         self._error_state_msg = ""
         self.verbose_level = verbose_level
@@ -145,11 +158,6 @@ class Project(object):
         self.fold_samples = pandas.DataFrame(columns=["ID", "X", "Y", "Z", "featureId"])
         self.geology_samples = pandas.DataFrame(columns=["ID", "X", "Y", "Z", "featureId"])
 
-        
-        # Check for alternate config filenames in kwargs
-        if "metadata_filename" in kwargs and config_filename == "":
-            config_filename = kwargs["metadata_filename"]
-
         # Sanity check on working projection parameter
         if issubclass(type(working_projection), str) or issubclass(type(working_projection), int):
             self.map_data.set_working_projection(working_projection)
@@ -207,12 +215,14 @@ class Project(object):
             self.map_data.set_config_filename(config_filename)
 
         if config_dictionary != {}:
+            validate_config_dictionary(config_dictionary)
             self.map_data.config.update_from_dictionary(config_dictionary)
+            # print(self.map_data.config)
+            # self.map_data.config.validate_config_dictionary(config_dictionary)
             
         if clut_filename != "":
             self.map_data.set_colour_filename(clut_filename)
             
-
         
         # Load all data (both shape and raster)
         self.map_data.load_all_map_data()
@@ -230,9 +240,59 @@ class Project(object):
         self.stratigraphic_column.populate(self.map_data.get_map_data(Datatype.GEOLOGY))
         self.deformation_history.populate(self.map_data.get_map_data(Datatype.FAULT))
 
-        if len(kwargs):
-            logger.warning(f"Unused keyword arguments: {kwargs}")
 
+    @beartype.beartype
+    def validate_required_inputs(
+        self,
+        bounding_box: Dict[str, Union[float, int]],
+        working_projection: str,
+        geology_filename: str,
+        structure_filename: str,
+        dtm_filename: str,
+        config_filename: str = None,
+        config_dictionary: Dict[str, Any] = {},
+    ) -> None:
+
+        required_inputs = {
+            "bounding_box": bounding_box,
+            "working_projection": working_projection, # this may be removed when fix is added for https://github.com/Loop3D/map2loop/issues/103
+            "geology_filename": geology_filename,
+            "structure_filename": structure_filename,
+            "dtm_filename": dtm_filename,
+        }
+
+        # Check for missing required inputs in project
+        missing_inputs = [key for key, value in required_inputs.items() if not value]
+
+        if missing_inputs:
+            missing_list = ", ".join(missing_inputs)
+            logger.error(
+                f"Project construction is missing required inputs: {missing_list}. "
+                "Please add them to the Project()."
+            )
+            raise ValueError(
+                f"Project construction is missing required inputs: {missing_list}. "
+                "Please add them to the Project()."
+            )
+
+        # Either config_filename or config_dictionary must be provided (but not both or neither)
+        if not config_filename and not config_dictionary:
+            logger.error(
+                "A config file is required to run map2loop - use either 'config_filename' or 'config_dictionary' to initialise the project."
+            )
+            raise ValueError(
+                 "A config file is required to run map2loop - use either 'config_filename' or 'config_dictionary' to initialise the project."
+            )
+        if config_filename and config_dictionary:
+            logger.error(
+                "Both 'config_filename' and 'config_dictionary' were provided. Please specify only one config."
+            )
+            raise ValueError(
+                "Both 'config_filename' and 'config_dictionary' were provided. Please specify only one config."
+            )
+
+            
+    
     # Getters and Setters
     @beartype.beartype
     def set_ignore_lithology_codes(self, codes: list):
@@ -734,9 +794,10 @@ class Project(object):
         logger.info('Saving data into loop project file')
         if not self.loop_filename:
             logger.info('No loop project file specified, creating a new one')
-            self.loop_filename = os.path.join(
-                self.map_data.tmp_path, os.path.basename(self.map_data.tmp_path) + ".loop3d"
-            )
+            output_dir = pathlib.Path.cwd()  
+            output_dir.mkdir(parents=True, exist_ok=True) 
+            filename = "new_project.loop3d"
+            self.loop_filename = str(output_dir / filename)
 
         file_exists = os.path.isfile(self.loop_filename)
 
@@ -1012,7 +1073,7 @@ class Project(object):
         gdf.plot(ax=base, marker="o", color="red", markersize=5)
 
     @beartype.beartype
-    def save_mapdata_to_files(self, save_path: str = ".", extension: str = ".shp.zip"):
+    def save_mapdata_to_files(self, save_path: Union[pathlib.Path,str], extension: str = ".shp.zip"):
         """
         Saves the map data frames to csv files
 
@@ -1022,8 +1083,10 @@ class Project(object):
             extension (str, optional):
                 An alternate extension to save the GeoDataFrame in. Defaults to ".csv".
         """
-        if not os.path.exists(save_path):
-            os.mkdir(save_path)
+        
+        save_path=pathlib.Path(save_path)
+        if not save_path.exists():
+            os.makedirs(save_path)
         self.map_data.save_all_map_data(save_path, extension)
 
     @beartype.beartype
